@@ -33,14 +33,13 @@
 	return(x)
 }
 
-# temporary tricks to move avoid .Calling rgdal as per CRAN request
-# next version of raster should depend on rgdal > "0.7-12"
+# temporary tricks to avoid .Calling rgdal as per CRAN request
 
 .gd_SetNoDataValue <- function(object, NAflag) {
 	if (isTRUE(getOption('rasterNewRGDALVersion'))) {
 		rgdal:::.gd_SetNoDataValue(object, NAflag)
 	} else {
-		.Call("RGDAL_SetNoDataValue", object, as.double(NAflag), PACKAGE="rgdal")
+		stop("you need a newer version of rgdal to use this function")
 	}
 }
 
@@ -49,7 +48,7 @@
 	if (getOption('rasterNewRGDALVersion')) {
 		rgdal:::.gd_SetGeoTransform(object, geotrans)
 	} else {
-		.Call("RGDAL_SetGeoTransform", object, geotrans, PACKAGE="rgdal")
+		stop("you need a newer version of rgdal to use this function")
 	}
 }
 
@@ -58,7 +57,7 @@
 	if (getOption('rasterNewRGDALVersion')) {
 		rgdal:::.gd_SetProject(object, proj4string)	
 	} else {
-		.Call("RGDAL_SetProject", object, proj4string, PACKAGE="rgdal")
+		stop("you need a newer version of rgdal to use this function")
 	}
 }
 
@@ -67,7 +66,7 @@
 	if (getOption('rasterNewRGDALVersion')) {
 		rgdal:::.gd_SetStatistics(object, statistics)
 	} else {
-		.Call("RGDAL_SetStatistics", object, as.double(statistics), PACKAGE="rgdal")
+		stop("you need a newer version of rgdal to use this function")
 	}
 }
 
@@ -75,7 +74,7 @@
 	if (getOption('rasterNewRGDALVersion')) {
 		rgdal:::.gd_transform(projfrom, projto, n, x, y)
 	} else {
-		.Call("transform", projfrom, projto, n, x, y, PACKAGE="rgdal")
+		stop("you need a newer version of rgdal to use this function")
 	}
 }
 
