@@ -6,8 +6,23 @@
 
 setMethod("[[", "Raster",
 function(x,i,j,...,drop=TRUE) {
-	if ( missing(i)) { stop('you must provide an index') }
-	if (! missing(j)) { warning('second index is ignored') }
+	if ( missing(i)) { 
+		stop('you must provide an index') 
+	}
+	if (! missing(j)) { 
+		warning('second index is ignored') 
+	}
+	if (is.numeric(i)) {
+		sgn <- sign(i)
+		sgn[sgn==0] <- 1
+		if (! all(sgn == 1) ) {
+			if (! all(sgn == -1) ) {
+				stop("only 0's may be mixed with negative subscripts")
+			} else {
+				i <- (1:nlayers(x))[i]
+			}
+		}
+	}
 	subset(x, i, drop=drop)
 })
 
@@ -32,7 +47,7 @@ setReplaceMethod("[[", c("RasterStack", "numeric", "missing"),
 			}
 			value[] <- val
 		} else {
-			compare(x, value)
+			compareRaster(x, value)
 		}
 		
 		if (i > nl) {
@@ -46,13 +61,55 @@ setReplaceMethod("[[", c("RasterStack", "numeric", "missing"),
 
 
 
+setReplaceMethod("[[", c("RasterBrick", "numeric", "missing"),
+	function(x, i, j, value) {
+		i <- round(i)
+
+		if (i < 1) {
+			stop('index should be > 0')
+		}
+		nl <- nlayers(x)
+		if (i > nl + 1) {
+			stop('index should be <= nlayers(x)+1')
+		}
+		
+		if (canProcessInMemory(x)) {
+			if (!inMemory(x)) {
+				x <- readAll(x)
+			}
+			if (!inherits(value, 'RasterLayer')) {
+				val <- value
+				if (i > nl) {
+					value <- getValues(x[[nl]])
+				} else {
+					value <- getValues(x[[i]])
+				}
+				# for recycling
+				value[] <- val
+			} else {
+				compareRaster(x, value)
+				value <- getValues(value)
+			}
+			x <- setValues(x, value, i)
+		} else {
+			x <- stack(x)
+			x[[i]] <- value
+		}	
+		return(x)
+	}
+)
+
+
+
+
+
 
 setReplaceMethod("[", c("RasterStackBrick", "Raster", "missing"),
 	function(x, i, j, value) {
 	
 		if (! hasValues(i) ) {
 			i <- cellsFromExtent(x, i)
-		} else if (compare(x, i, stopiffalse=FALSE, showwarning=FALSE)) {
+		} else if (compareRaster(x, i, stopiffalse=FALSE, showwarning=FALSE)) {
 			dims <- dim(i)
 			i <- as.logical(getValues(i))
 			dim(i) <- c(prod(dims[1:2]), dims[3])
