@@ -26,7 +26,7 @@ setMethod("Math", signature(x='Raster'),
 					r <- setValues(r, do.call(funname, list(values(x))))
 				} else {
 					tr <- blockSize(x)
-					pb <- pbCreate(tr$n)			
+					pb <- pbCreate(tr$n, label='math')			
 					r <- writeStart(r, filename=rasterTmpFile(), overwrite=TRUE )
 					last <- 0
 					for (i in 1:tr$n) {
@@ -51,7 +51,7 @@ setMethod("Math", signature(x='Raster'),
 			} else {
 			
 				tr <- blockSize(x)
-				pb <- pbCreate(tr$n)			
+				pb <- pbCreate(tr$n, label='math')
 				r <- writeStart(r, filename=rasterTmpFile(), overwrite=TRUE )
 				for (i in 1:tr$n) {
 					v <- t( apply(getValues(x, row=tr$row[i], nrows=tr$nrows[i]), 1, funname) )
@@ -74,7 +74,7 @@ setMethod("Math", signature(x='Raster'),
 				}
 			
 				tr <- blockSize(x)
-				pb <- pbCreate(tr$n)			
+				pb <- pbCreate(tr$n, label='math')
 				r <- writeStart(r, filename=rasterTmpFile(), datatype=datatype, overwrite=TRUE )
 				for (i in 1:tr$n) {
 					v <- callGeneric( getValues(x, row=tr$row[i], nrows=tr$nrows[i]) )
@@ -129,7 +129,7 @@ setMethod("Math2", signature(x='Raster'),
 			}
 
 			tr <- blockSize(x)
-			pb <- pbCreate(tr$n)			
+			pb <- pbCreate(tr$n, label='math')
 			r <- writeStart(r, filename=rasterTmpFile(), datatype=datatype, format=.filetype(), overwrite=TRUE )
 			for (i in 1:tr$n) {
 				v <- callGeneric( getValues(x, row=tr$row[i], nrows=tr$nrows[i]), digits )
@@ -164,7 +164,7 @@ setMethod("log", signature(x='Raster'),
 			r <- setValues(r, log(values(x), base=base))
 		} else {
 			tr <- blockSize(x)
-			pb <- pbCreate(tr$n)			
+			pb <- pbCreate(tr$n, label='math')
 			r <- writeStart(r, '', overwrite=TRUE )
 			for (i in 1:tr$n) {
 				v <- log( getValues(x, row=tr$row[i], nrows=tr$nrows[i]), base=base )
