@@ -1,6 +1,6 @@
-# Author: Robert J. Hijmans, r.hijmans@gmail.com
+# Author: Robert J. Hijmans
 # Date :  January 2009
-# Version 0.9
+# Version 1.0
 # Licence GPL v3
 
 
@@ -140,7 +140,7 @@ projectRaster <- function(from, to, res, crs, method="bilinear", alignOnly=FALSE
 		if (missing(crs)) {
 			stop("'crs' argument is missing.")
 		}
-		projto <- crs
+		projto <- projection(crs)
 		to <- projectExtent(from, projto)
 		if (missing(res)) {
 			res <- .computeRes(from, projto)
@@ -256,8 +256,7 @@ projectRaster <- function(from, to, res, crs, method="bilinear", alignOnly=FALSE
 			v <- matrix(nrow=length(cells), ncol=nl)
 			if (nrow(xy) > 0) {
 				ci <- match(cellFromXY(to, xy), cells)
-				xy <- .Call("transform", projto_int, projfrom, nrow(xy), xy[,1], xy[,2], PACKAGE="rgdal")
-				#xy <- .gd_transform( projto_int, projfrom, nrow(xy), xy[,1], xy[,2] )
+				xy <- rgdal:::.gd_transform(projto_int, projfrom, nrow(xy), xy[,1], xy[,2])
 				xy <- cbind(xy[[1]], xy[[2]])
 				v[ci, ] <- .xyValues(from, xy, method=method)
 			} 
